References
==========

.. [Gotoh1982] Gotoh, O. 1982.  *An Improved Algorithm for Matching Biological
               Sequences.*  J. Mol. Biol. 162, 705-708
               http://jaligner.sourceforge.net/references/gotoh1982.pdf

.. [NeedlemanWunsch1970] Needleman, S.  Wunsch, C.  1970.  *A General Method Applicable to the
                         Search for Similarities in the Amino Acid Sequence of Two
                         Proteins.*  J. Mol. Biol. 48, 443-453
